@@ -21,12 +21,13 @@ var scan = function(dir, suffix,fullpath, callback) {
       var filePath = dir + '/' + file;
       fs.stat(filePath, function(err, stat) {
         if (err) {
-          return next(err);
+           next();
         }
         if (stat.isDirectory()) {
           scan(filePath, suffix,fullpath, function(err, results) {
             if (err) {
-              return next(err);
+               
+               next();
             }
             returnFiles = returnFiles.concat(results);
             next();
